==> featherpad_0.9.0.orig.tar.gz: FeatherPad-0.9.0/README.md <==
# FeatherPad

## Overview

FeatherPad (by Pedram Pourang, a.k.a. Tsu Jan <tsujan2000@gmail.com>) is a lightweight Qt5 plain-text editor for Linux. It is independent of any desktop environment and has:

  * Drag-and-drop support, including tab detachment and attachment;
  * X11 virtual desktop awareness (using tabs on current desktop but opening a new window on another);
  * An optionally permanent search-bar with a different search entry for each tab;
  * Instant highlighting of found matches when searching;
  * A docked window for text replacement;
  * Support for showing line numbers and jumping to a specific line;
  * Automatic detection of text encoding as far as possible and optional saving with encoding;
  * Syntax highlighting for common programming languages;
  * Session management;
  * Side-pane mode;
  * Auto-saving;
  * Printing;
  * Text zooming;
  * Appropriate but non-interrupting prompts; and
  * Other features that can be found in its settings, on its menus or when it is actually used.

Please see INSTALL for instructions on compilation, installation and translation!

FeatherPad was written in GTK+ at first, then ported to Qt with more features. Its homepage is <https://github.com/tsujan/FeatherPad>.

## Screenshots

The active Qt widget style determines the look and feel of every Qt application. The following screenshots are taken with a Kvantum theme and the dark color scheme of FeatherPad:

![Tabs](screenshots/Tabs.png?raw=true "Tabs")
![Side-Pane](screenshots/Side-Pane.png?raw=true "Side-Pane")

==> featherpad_0.9.2.orig.tar.gz: FeatherPad-0.9.2/README.md <==
# FeatherPad

## Overview

FeatherPad (by Pedram Pourang, a.k.a. Tsu Jan <tsujan2000@gmail.com>) is a lightweight Qt5 plain-text editor for Linux. It is independent of any desktop environment and has:

  * Drag-and-drop support, including tab detachment and attachment;
  * X11 virtual desktop awareness (using tabs on current desktop but opening a new window on another);
  * An optionally permanent search-bar with a different search entry for each tab;
  * Instant highlighting of found matches when searching;
  * A docked window for text replacement;
  * Support for showing line numbers and jumping to a specific line;
  * Automatic detection of text encoding as far as possible and optional saving with encoding;
  * Syntax highlighting for common programming languages;
  * Ability to open URLs with appropriate applications;
  * Session management;
  * Side-pane mode;
  * Auto-saving;
  * Printing;
  * Text zooming;
  * Appropriate but non-interrupting prompts;
  * Haiku OS support; and
  * Other features that can be found in its settings, on its menus or when it is actually used.

Please see INSTALL for instructions on compilation, installation and translation! (For translations, also see below.)

FeatherPad was written in GTK+ at first, then ported to Qt with more features. Its homepage is <https://github.com/tsujan/FeatherPad>.

## Screenshots

The active Qt widget style determines the look and feel of every Qt application. The following screenshots are taken with a Kvantum theme and the dark color scheme of FeatherPad:

![Tabs](screenshots/Tabs.png?raw=true "Tabs")
![Side-Pane](screenshots/Side-Pane.png?raw=true "Side-Pane")

## Translations
FeatherPad is being translated using Weblate, a web tool designed to ease translating for both developers and translators.
If you would like to contribute to translation of FeatherPad, you need to register on this server.

<a href="https://weblate.lxqt.org/engage/tsujan/?utm_source=widget">
<img src="https://weblate.lxqt.org/widgets/tsujan/-/featherpad/multi-auto.svg" alt="Translation status" />
</a>
